.. _developing_galaxy:

***************
Developer Guide
***************

You can host collections and roles on Galaxy to share with the Ansible community. Galaxy content is formated in pre-packaged units of work such as `roles <playbooks_reuse_roles>`_, and new in Galaxy 3.2, `collections <collections>`_.
You can create roles for provisioning infrastructure, deploying applications, and all of the tasks you do everyday. Taking this a step further, you can create collections which provide a comprehensive package of automation that may include multiple playbooks, roles, modules, and plugins.

.. toctree::
   :maxdepth: 2

   creating_collections
   creating_roles

.. seealso::
  `collections <collections>`_
    Sharable collections of modules, playbooks and roles
  `roles <playbooks_reuse_roles>`_
    Reusable tasks, handlers, and other files in a known directory structure
